from enum import Enum

class ObjectType(Enum):
    analogInput: int
    analogOutput: int
    analogValue: int
    binaryInput: int
    binaryOutput: int
    binaryValue: int
    calendar: int
    command: int
    device: int
    eventEnrollment: int
    file: int
    group: int
    loop: int
    multiStateInput: int
    multiStateOutput: int
    notificationClass: int
    program: int
    schedule: int
    averaging: int
    multiStateValue: int
    trendLog: int
    lifeSafetyPoint: int
    lifeSafetyZone: int
    accumulator: int
    pulseConverter: int
    eventLog: int
    globalGroup: int
    trendLogMultiple: int
    loadControl: int
    structuredView: int
    accessDoor: int
    timer: int
    accessCredential: int
    accessPoint: int
    accessRights: int
    accessUser: int
    accessZone: int
    credentialDataInput: int
    networkSecurity: int
    bitstringValue: int
    characterstringValue: int
    datePatternValue: int
    dateValue: int
    datetimePatternValue: int
    datetimeValue: int
    integerValue: int
    largeAnalogValue: int
    octetstringValue: int
    positiveIntegerValue: int
    timePatternValue: int
    timeValue: int
    notificationForwarder: int
    alertEnrollment: int
    channel: int
    lightingOutput: int
    binaryLightingOutput: int
    networkPort: int
    elevatorGroup: int
    escalator: int
    lift: int

class PropertyIdentifier(Enum):
    ackedTransitions: int
    ackRequired: int
    action: int
    actionText: int
    activeText: int
    activeVtSessions: int
    alarmValue: int
    alarmValues: int
    all: int
    allWritesSuccessful: int
    apduSegmentTimeout: int
    apduTimeout: int
    applicationSoftwareVersion: int
    archive: int
    bias: int
    changeOfStateCount: int
    changeOfStateTime: int
    notificationClass: int
    controlledVariableReference: int
    controlledVariableUnits: int
    controlledVariableValue: int
    covIncrement: int
    dateList: int
    daylightSavingsStatus: int
    deadband: int
    derivativeConstant: int
    derivativeConstantUnits: int
    description: int
    descriptionOfHalt: int
    deviceAddressBinding: int
    deviceType: int
    effectivePeriod: int
    elapsedActiveTime: int
    errorLimit: int
    eventEnable: int
    eventState: int
    eventType: int
    exceptionSchedule: int
    faultValues: int
    feedbackValue: int
    fileAccessMethod: int
    fileSize: int
    fileType: int
    firmwareRevision: int
    highLimit: int
    inactiveText: int
    inProcess: int
    instanceOf: int
    integralConstant: int
    integralConstantUnits: int
    limitEnable: int
    listOfGroupMembers: int
    listOfObjectPropertyReferences: int
    localDate: int
    localTime: int
    location: int
    lowLimit: int
    manipulatedVariableReference: int
    maximumOutput: int
    maxApduLengthAccepted: int
    maxInfoFrames: int
    maxMaster: int
    maxPresValue: int
    minimumOffTime: int
    minimumOnTime: int
    minimumOutput: int
    minPresValue: int
    modelName: int
    modificationDate: int
    notifyType: int
    numberOfApduRetries: int
    numberOfStates: int
    objectIdentifier: int
    objectList: int
    objectName: int
    objectPropertyReference: int
    objectType: int
    optional: int
    outOfService: int
    outputUnits: int
    eventParameters: int
    polarity: int
    presentValue: int
    priority: int
    priorityArray: int
    priorityForWriting: int
    processIdentifier: int
    programChange: int
    programLocation: int
    programState: int
    proportionalConstant: int
    proportionalConstantUnits: int
    protocolObjectTypesSupported: int
    protocolServicesSupported: int
    protocolVersion: int
    readOnly: int
    reasonForHalt: int
    recipientList: int
    reliability: int
    relinquishDefault: int
    required: int
    resolution: int
    segmentationSupported: int
    setpoint: int
    setpointReference: int
    stateText: int
    statusFlags: int
    systemStatus: int
    timeDelay: int
    timeOfActiveTimeReset: int
    timeOfStateCountReset: int
    timeSynchronizationRecipients: int
    units: int
    updateInterval: int
    utcOffset: int
    vendorIdentifier: int
    vendorName: int
    vtClassesSupported: int
    weeklySchedule: int
    attemptedSamples: int
    averageValue: int
    bufferSize: int
    clientCovIncrement: int
    covResubscriptionInterval: int
    eventTimeStamps: int
    logBuffer: int
    logDeviceObjectProperty: int
    enable: int
    logInterval: int
    maximumValue: int
    minimumValue: int
    notificationThreshold: int
    protocolRevision: int
    recordsSinceNotification: int
    recordCount: int
    startTime: int
    stopTime: int
    stopWhenFull: int
    totalRecordCount: int
    validSamples: int
    windowInterval: int
    windowSamples: int
    maximumValueTimestamp: int
    minimumValueTimestamp: int
    varianceValue: int
    activeCovSubscriptions: int
    backupFailureTimeout: int
    configurationFiles: int
    databaseRevision: int
    directReading: int
    lastRestoreTime: int
    maintenanceRequired: int
    memberOf: int
    mode: int
    operationExpected: int
    setting: int
    silenced: int
    trackingValue: int
    zoneMembers: int
    lifeSafetyAlarmValues: int
    maxSegmentsAccepted: int
    profileName: int
    autoSlaveDiscovery: int
    manualSlaveAddressBinding: int
    slaveAddressBinding: int
    slaveProxyEnable: int
    lastNotifyRecord: int
    scheduleDefault: int
    acceptedModes: int
    adjustValue: int
    count: int
    countBeforeChange: int
    countChangeTime: int
    covPeriod: int
    inputReference: int
    limitMonitoringInterval: int
    loggingObject: int
    loggingRecord: int
    prescale: int
    pulseRate: int
    scale: int
    scaleFactor: int
    updateTime: int
    valueBeforeChange: int
    valueSet: int
    valueChangeTime: int
    alignIntervals: int
    intervalOffset: int
    lastRestartReason: int
    loggingType: int
    restartNotificationRecipients: int
    timeOfDeviceRestart: int
    timeSynchronizationInterval: int
    trigger: int
    utcTimeSynchronizationRecipients: int
    nodeSubtype: int
    nodeType: int
    structuredObjectList: int
    subordinateAnnotations: int
    subordinateList: int
    actualShedLevel: int
    dutyWindow: int
    expectedShedLevel: int
    fullDutyBaseline: int
    requestedShedLevel: int
    shedDuration: int
    shedLevelDescriptions: int
    shedLevels: int
    stateDescription: int
    doorAlarmState: int
    doorExtendedPulseTime: int
    doorMembers: int
    doorOpenTooLongTime: int
    doorPulseTime: int
    doorStatus: int
    doorUnlockDelayTime: int
    lockStatus: int
    maskedAlarmValues: int
    securedStatus: int
    absenteeLimit: int
    accessAlarmEvents: int
    accessDoors: int
    accessEvent: int
    accessEventAuthenticationFactor: int
    accessEventCredential: int
    accessEventTime: int
    accessTransactionEvents: int
    accompaniment: int
    accompanimentTime: int
    activationTime: int
    activeAuthenticationPolicy: int
    assignedAccessRights: int
    authenticationFactors: int
    authenticationPolicyList: int
    authenticationPolicyNames: int
    authenticationStatus: int
    authorizationMode: int
    belongsTo: int
    credentialDisable: int
    credentialStatus: int
    credentials: int
    credentialsInZone: int
    daysRemaining: int
    entryPoints: int
    exitPoints: int
    expirationTime: int
    extendedTimeEnable: int
    failedAttemptEvents: int
    failedAttempts: int
    failedAttemptsTime: int
    lastAccessEvent: int
    lastAccessPoint: int
    lastCredentialAdded: int
    lastCredentialAddedTime: int
    lastCredentialRemoved: int
    lastCredentialRemovedTime: int
    lastUseTime: int
    lockout: int
    lockoutRelinquishTime: int
    maxFailedAttempts: int
    members: int
    musterPoint: int
    negativeAccessRules: int
    numberOfAuthenticationPolicies: int
    occupancyCount: int
    occupancyCountAdjust: int
    occupancyCountEnable: int
    occupancyLowerLimit: int
    occupancyLowerLimitEnforced: int
    occupancyState: int
    occupancyUpperLimit: int
    occupancyUpperLimitEnforced: int
    passbackMode: int
    passbackTimeout: int
    positiveAccessRules: int
    reasonForDisable: int
    supportedFormats: int
    supportedFormatClasses: int
    threatAuthority: int
    threatLevel: int
    traceFlag: int
    transactionNotificationClass: int
    userExternalIdentifier: int
    userInformationReference: int
    userName: int
    userType: int
    usesRemaining: int
    zoneFrom: int
    zoneTo: int
    accessEventTag: int
    globalIdentifier: int
    verificationTime: int
    baseDeviceSecurityPolicy: int
    distributionKeyRevision: int
    doNotHide: int
    keySets: int
    lastKeyServer: int
    networkAccessSecurityPolicies: int
    packetReorderTime: int
    securityPduTimeout: int
    securityTimeWindow: int
    supportedSecurityAlgorithms: int
    updateKeySetTimeout: int
    backupAndRestoreState: int
    backupPreparationTime: int
    restoreCompletionTime: int
    restorePreparationTime: int
    bitMask: int
    bitText: int
    isUtc: int
    groupMembers: int
    groupMemberNames: int
    memberStatusFlags: int
    requestedUpdateInterval: int
    covuPeriod: int
    covuRecipients: int
    eventMessageTexts: int
    eventMessageTextsConfig: int
    eventDetectionEnable: int
    eventAlgorithmInhibit: int
    eventAlgorithmInhibitRef: int
    timeDelayNormal: int
    reliabilityEvaluationInhibit: int
    faultParameters: int
    faultType: int
    localForwardingOnly: int
    processIdentifierFilter: int
    subscribedRecipients: int
    portFilter: int
    authorizationExemptions: int
    allowGroupDelayInhibit: int
    channelNumber: int
    controlGroups: int
    executionDelay: int
    lastPriority: int
    writeStatus: int
    propertyList: int
    serialNumber: int
    blinkWarnEnable: int
    defaultFadeTime: int
    defaultRampRate: int
    defaultStepIncrement: int
    egressTime: int
    inProgress: int
    instantaneousPower: int
    lightingCommand: int
    lightingCommandDefaultPriority: int
    maxActualValue: int
    minActualValue: int
    power: int
    transition: int
    egressActive: int
    interfaceValue: int
    faultHighLimit: int
    faultLowLimit: int
    lowDiffLimit: int
    strikeCount: int
    timeOfStrikeCountReset: int
    defaultTimeout: int
    initialTimeout: int
    lastStateChange: int
    stateChangeValues: int
    timerRunning: int
    timerState: int
    apduLength: int
    ipAddress: int
    ipDefaultGateway: int
    ipDhcpEnable: int
    ipDhcpLeaseTime: int
    ipDhcpLeaseTimeRemaining: int
    ipDhcpServer: int
    ipDnsServer: int
    bacnetIpGlobalAddress: int
    bacnetIpMode: int
    bacnetIpMulticastAddress: int
    bacnetIpNatTraversal: int
    ipSubnetMask: int
    bacnetIpUdpPort: int
    bbmdAcceptFdRegistrations: int
    bbmdBroadcastDistributionTable: int
    bbmdForeignDeviceTable: int
    changesPending: int
    command: int
    fdBbmdAddress: int
    fdSubscriptionLifetime: int
    linkSpeed: int
    linkSpeeds: int
    linkSpeedAutonegotiate: int
    macAddress: int
    networkInterfaceName: int
    networkNumber: int
    networkNumberQuality: int
    networkType: int
    routingTable: int
    virtualMacAddressTable: int
    commandTimeArray: int
    currentCommandPriority: int
    lastCommandTime: int
    valueSource: int
    valueSourceArray: int
    bacnetIpv6Mode: int
    ipv6Address: int
    ipv6PrefixLength: int
    bacnetIpv6UdpPort: int
    ipv6DefaultGateway: int
    bacnetIpv6MulticastAddress: int
    ipv6DnsServer: int
    ipv6AutoAddressingEnable: int
    ipv6DhcpLeaseTime: int
    ipv6DhcpLeaseTimeRemaining: int
    ipv6DhcpServer: int
    ipv6ZoneIndex: int
    assignedLandingCalls: int
    carAssignedDirection: int
    carDoorCommand: int
    carDoorStatus: int
    carDoorText: int
    carDoorZone: int
    carDriveStatus: int
    carLoad: int
    carLoadUnits: int
    carMode: int
    carMovingDirection: int
    carPosition: int
    elevatorGroup: int
    energyMeter: int
    energyMeterRef: int
    escalatorMode: int
    faultSignals: int
    floorText: int
    groupId: int
    groupMode: int
    higherDeck: int
    installationId: int
    landingCalls: int
    landingCallControl: int
    landingDoorStatus: int
    lowerDeck: int
    machineRoomId: int
    makingCarCall: int
    nextStoppingFloor: int
    operationDirection: int
    passengerAlarm: int
    powerMode: int
    registeredCarCall: int
    activeCovMultipleSubscriptions: int
    protocolLevel: int
    referencePort: int
    deployedProfileLocation: int
    profileLocation: int
    tags: int
    subordinateNodeTypes: int
    subordinateTags: int
    subordinateRelationships: int
    defaultSubordinateRelationship: int
    represents: int
