from typing import List

from java.lang import Object

class PageFormat(Object):
    LANDSCAPE: int
    PORTRAIT: int
    REVERSE_LANDSCAPE: int
    def clone(self) -> Object: ...
    def getHeight(self) -> float: ...
    def getImageableHeight(self) -> float: ...
    def getImageableWidth(self) -> float: ...
    def getImageableX(self) -> float: ...
    def getImageableY(self) -> float: ...
    def getMatrix(self) -> List[float]: ...
    def getOrientation(self) -> int: ...
    def getPaper(self) -> Paper: ...
    def setOrientation(self, orientation: int) -> None: ...
    def setPaper(self, paper: Paper) -> None: ...

class Paper(Object):
    def clone(self) -> Object: ...
    def getHeight(self) -> float: ...
    def getImageableHeight(self) -> float: ...
    def getImageableWidth(self) -> float: ...
    def getImageableX(self) -> float: ...
    def getImageableY(self) -> float: ...
    def getWidth(self) -> float: ...
    def setImageableArea(
        self, x: float, y: float, width: float, height: float
    ) -> None: ...
    def setSize(self, width: float, height: float) -> None: ...
