from typing import Any

from dev.coatl.helper.types import AnyStr
from java.lang import Class

class TypeBuilder:
    def getBase(self) -> Class: ...
    def getDict(self, var1: Any) -> Any: ...
    def getDoc(self) -> AnyStr: ...
    def getIsBaseType(self) -> bool: ...
    def getName(self) -> AnyStr: ...
    def getTypeClass(self) -> Class: ...
